@@ -1,13 +1,11 @@
-from .utils import check_created
+
+from .base import ResourceBase
 
 
-class Callback:
+class Callback(ResourceBase):
 
     resource = 'callback'
 
-    def __init__(self, nuvla):
-        self.nuvla = nuvla
-
     def create(self, action_name, target_resource, data=None, expires=None, acl=None):
         """
         :param action_name: name of the action
@@ -28,6 +26,4 @@ class Callback:
         if acl:
             callback.update({"acl": acl})
 
-        resource_id = check_created(self.nuvla.add(self.resource, callback),
-                                    'Failed to create callback.')
-        return resource_id
+        return self.add(callback)
